@@ -17,9 +17,7 @@
 
 package opennlp.dl.doccat;
 
-import java.io.BufferedReader;
 import java.io.File;
-import java.io.FileReader;
 import java.io.IOException;
 import java.nio.LongBuffer;
 import java.util.Arrays;
@@ -37,43 +35,47 @@ import ai.onnxruntime.OnnxTensor;
 import ai.onnxruntime.OrtEnvironment;
 import ai.onnxruntime.OrtException;
 import ai.onnxruntime.OrtSession;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
+import opennlp.dl.AbstractDL;
 import opennlp.dl.InferenceOptions;
 import opennlp.dl.Tokens;
 import opennlp.dl.doccat.scoring.ClassificationScoringStrategy;
 import opennlp.tools.doccat.DocumentCategorizer;
-import opennlp.tools.tokenize.Tokenizer;
 import opennlp.tools.tokenize.WordpieceTokenizer;
 
 /**
  * An implementation of {@link DocumentCategorizer} that performs document classification
  * using ONNX models.
+ *
+ * @see DocumentCategorizer
+ * @see InferenceOptions
+ * @see ClassificationScoringStrategy
  */
-public class DocumentCategorizerDL implements DocumentCategorizer {
+public class DocumentCategorizerDL extends AbstractDL implements DocumentCategorizer {
 
-  public static final String INPUT_IDS = "input_ids";
-  public static final String ATTENTION_MASK = "attention_mask";
-  public static final String TOKEN_TYPE_IDS = "token_type_ids";
+  private static final Logger logger = LoggerFactory.getLogger(DocumentCategorizerDL.class);
 
-  private final Tokenizer tokenizer;
-  private final Map<String, Integer> vocabulary;
   private final Map<Integer, String> categories;
   private final ClassificationScoringStrategy classificationScoringStrategy;
   private final InferenceOptions inferenceOptions;
-  protected final OrtEnvironment env;
-  protected final OrtSession session;
 
   /**
-   * Creates a new document categorizer using ONNX models.
+   * Instantiates a {@link DocumentCategorizer document categorizer} using ONNX models.
+   *
    * @param model The ONNX model file.
-   * @param vocab The model's vocabulary file.
+   * @param vocabulary The model file's vocabulary file.
    * @param categories The categories.
    * @param classificationScoringStrategy Implementation of {@link ClassificationScoringStrategy} used
    *                                      to calculate the classification scores given the score of each
    *                                      individual document part.
    * @param inferenceOptions {@link InferenceOptions} to control the inference.
+   *
+   * @throws OrtException Thrown if the {@code model} cannot be loaded.
+   * @throws IOException Thrown if errors occurred loading the {@code model} or {@code vocabulary}.
    */
-  public DocumentCategorizerDL(File model, File vocab, Map<Integer, String> categories,
+  public DocumentCategorizerDL(File model, File vocabulary, Map<Integer, String> categories,
                                ClassificationScoringStrategy classificationScoringStrategy,
                                InferenceOptions inferenceOptions)
       throws IOException, OrtException {
@@ -86,8 +88,8 @@ public class DocumentCategorizerDL implements DocumentCategorizer {
     }
 
     this.session = env.createSession(model.getPath(), sessionOptions);
-    this.vocabulary = loadVocab(vocab);
-    this.tokenizer = new WordpieceTokenizer(vocabulary.keySet());
+    this.vocab = loadVocab(vocabulary);
+    this.tokenizer = new WordpieceTokenizer(vocab.keySet());
     this.categories = categories;
     this.classificationScoringStrategy = classificationScoringStrategy;
     this.inferenceOptions = inferenceOptions;
@@ -108,16 +110,16 @@ public class DocumentCategorizerDL implements DocumentCategorizer {
         final Map<String, OnnxTensor> inputs = new HashMap<>();
 
         inputs.put(INPUT_IDS, OnnxTensor.createTensor(env,
-            LongBuffer.wrap(t.getIds()), new long[] {1, t.getIds().length}));
+            LongBuffer.wrap(t.ids()), new long[] {1, t.ids().length}));
 
         if (inferenceOptions.isIncludeAttentionMask()) {
           inputs.put(ATTENTION_MASK, OnnxTensor.createTensor(env,
-              LongBuffer.wrap(t.getMask()), new long[] {1, t.getMask().length}));
+              LongBuffer.wrap(t.mask()), new long[] {1, t.mask().length}));
         }
 
         if (inferenceOptions.isIncludeTokenTypeIds()) {
           inputs.put(TOKEN_TYPE_IDS, OnnxTensor.createTensor(env,
-              LongBuffer.wrap(t.getTypes()), new long[] {1, t.getTypes().length}));
+              LongBuffer.wrap(t.types()), new long[] {1, t.types().length}));
         }
 
         // The outputs from the model.
@@ -132,7 +134,7 @@ public class DocumentCategorizerDL implements DocumentCategorizer {
       return classificationScoringStrategy.score(scores);
 
     } catch (Exception ex) {
-      System.err.println("Unload to perform document classification inference: " + ex.getMessage());
+      logger.error("Unload to perform document classification inference", ex);
     }
 
     return new double[]{};
@@ -220,33 +222,6 @@ public class DocumentCategorizerDL implements DocumentCategorizer {
 
   }
 
-  /**
-   * Loads a vocabulary file from disk.
-   * @param vocab The vocabulary file.
-   * @return A map of vocabulary words to integer IDs.
-   * @throws IOException Thrown if the vocabulary file cannot be opened and read.
-   */
-  private Map<String, Integer> loadVocab(File vocab) throws IOException {
-
-    final Map<String, Integer> v = new HashMap<>();
-
-    BufferedReader br = new BufferedReader(new FileReader(vocab.getPath()));
-    String line = br.readLine();
-    int x = 0;
-
-    while (line != null) {
-
-      line = br.readLine();
-      x++;
-
-      v.put(line, x);
-
-    }
-
-    return v;
-
-  }
-
   private Tokens oldTokenize(String text) {
 
     final String[] tokens = tokenizer.tokenize(text);
@@ -254,7 +229,7 @@ public class DocumentCategorizerDL implements DocumentCategorizer {
     final int[] ids = new int[tokens.length];
 
     for (int x = 0; x < tokens.length; x++) {
-      ids[x] = vocabulary.get(tokens[x]);
+      ids[x] = vocab.get(tokens[x]);
     }
 
     final long[] lids = Arrays.stream(ids).mapToLong(i -> i).toArray();
@@ -303,7 +278,7 @@ public class DocumentCategorizerDL implements DocumentCategorizer {
       final int[] ids = new int[tokens.length];
 
       for (int x = 0; x < tokens.length; x++) {
-        ids[x] = vocabulary.get(tokens[x]);
+        ids[x] = vocab.get(tokens[x]);
       }
 
       final long[] lids = Arrays.stream(ids).mapToLong(i -> i).toArray();
