@@ -26,12 +26,14 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import opennlp.tools.cmdline.AbstractCrossValidatorTool;
 import opennlp.tools.cmdline.CmdLineUtil;
 import opennlp.tools.cmdline.TerminateToolException;
 import opennlp.tools.cmdline.namefind.TokenNameFinderCrossValidatorTool.CVToolParams;
 import opennlp.tools.cmdline.params.CVParams;
-import opennlp.tools.cmdline.params.DetailedFMeasureEvaluatorParams;
 import opennlp.tools.cmdline.params.FineGrainedEvaluatorParams;
 import opennlp.tools.namefind.BilouCodec;
 import opennlp.tools.namefind.BioCodec;
@@ -48,18 +50,21 @@ import opennlp.tools.util.eval.EvaluationMonitor;
 public final class TokenNameFinderCrossValidatorTool
     extends AbstractCrossValidatorTool<NameSample, CVToolParams> {
 
-  interface CVToolParams extends TrainingParams, CVParams,
-      DetailedFMeasureEvaluatorParams, FineGrainedEvaluatorParams {
+  interface CVToolParams extends TrainingParams, CVParams, FineGrainedEvaluatorParams {
   }
 
+  private static final Logger logger = LoggerFactory.getLogger(TokenNameFinderCrossValidatorTool.class);
+
   public TokenNameFinderCrossValidatorTool() {
     super(NameSample.class, CVToolParams.class);
   }
 
+  @Override
   public String getShortDescription() {
     return "K-fold cross validator for the learnable Name Finder";
   }
 
+  @Override
   public void run(String format, String[] args) {
     super.run(format, args);
 
@@ -89,11 +94,6 @@ public final class TokenNameFinderCrossValidatorTool
     if (params.getMisclassified()) {
       listeners.add(new NameEvaluationErrorListener());
     }
-    TokenNameFinderDetailedFMeasureListener detailedFListener = null;
-    if (params.getDetailedF()) {
-      detailedFListener = new TokenNameFinderDetailedFMeasureListener();
-      listeners.add(detailedFListener);
-    }
 
     String sequenceCodecImplName = params.getSequenceCodec();
 
@@ -104,9 +104,12 @@ public final class TokenNameFinderCrossValidatorTool
       sequenceCodecImplName = BilouCodec.class.getName();
     }
 
-    SequenceCodec<String> sequenceCodec =
-        TokenNameFinderFactory.instantiateSequenceCodec(sequenceCodecImplName);
-
+    SequenceCodec<String> sequenceCodec;
+    try {
+      sequenceCodec = TokenNameFinderFactory.instantiateSequenceCodec(sequenceCodecImplName);
+    } catch (InvalidFormatException e) {
+      throw new TerminateToolException(-1, e.getMessage(), e);
+    }
 
     TokenNameFinderFineGrainedReportListener reportListener = null;
     File reportFile = params.getReportOutputFile();
@@ -138,7 +141,7 @@ public final class TokenNameFinderCrossValidatorTool
     try {
       validator = new TokenNameFinderCrossValidator(params.getLang(),
           params.getType(), mlParams, nameFinderFactory,
-          listeners.toArray(new TokenNameFinderEvaluationMonitor[listeners.size()]));
+          listeners.toArray(new TokenNameFinderEvaluationMonitor[0]));
       validator.evaluate(sampleStream, params.getFolds());
     } catch (IOException e) {
       throw createTerminationIOException(e);
@@ -150,18 +153,12 @@ public final class TokenNameFinderCrossValidatorTool
       }
     }
 
-    System.out.println("done");
-
-    System.out.println();
+    logger.info("done");
 
     if (reportFile != null) {
       reportListener.writeReport();
     }
 
-    if (detailedFListener == null) {
-      System.out.println(validator.getFMeasure());
-    } else {
-      System.out.println(detailedFListener);
-    }
+    logger.info(validator.getFMeasure().toString());
   }
 }
