@@ -37,7 +37,6 @@ import opennlp.tools.util.ObjectStream;
 import opennlp.tools.util.Span;
 import opennlp.tools.util.StringUtil;
 import opennlp.tools.util.TrainingParameters;
-import opennlp.tools.util.model.ModelUtil;
 
 /**
  * A sentence detector for splitting up raw text into sentences.
@@ -60,7 +59,7 @@ public class SentenceDetectorME implements SentenceDetector {
   /**
    * The maximum entropy model to use to evaluate contexts.
    */
-  private MaxentModel model;
+  private final MaxentModel model;
 
   /**
    * The feature context generator.
@@ -75,7 +74,7 @@ public class SentenceDetectorME implements SentenceDetector {
   /**
    * The list of probabilities associated with each decision.
    */
-  private List<Double> sentProbs = new ArrayList<>();
+  private final List<Double> sentProbs = new ArrayList<>();
 
   protected boolean useTokenEnd;
 
@@ -85,7 +84,7 @@ public class SentenceDetectorME implements SentenceDetector {
    * @throws IOException Thrown if the model cannot be downloaded or saved.
    */
   public SentenceDetectorME(String language) throws IOException {
-    this((SentenceModel) DownloadUtil.downloadModel(language, DownloadUtil.ModelType.SENTENCE_DETECTOR,
+    this(DownloadUtil.downloadModel(language, DownloadUtil.ModelType.SENTENCE_DETECTOR,
             SentenceModel.class));
   }
 
@@ -131,13 +130,14 @@ public class SentenceDetectorME implements SentenceDetector {
   }
 
   /**
-   * Detect sentences in a String.
+   * Detects sentences in given input {@link CharSequence}..
    *
-   * @param s  The string to be processed.
+   * @param s  The {@link CharSequence}. to be processed.
    *
    * @return   A string array containing individual sentences as elements.
    */
-  public String[] sentDetect(String s) {
+  @Override
+  public String[] sentDetect(CharSequence s) {
     Span[] spans = sentPosDetect(s);
     String[] sentences;
     if (spans.length != 0) {
@@ -152,29 +152,29 @@ public class SentenceDetectorME implements SentenceDetector {
     return sentences;
   }
 
-  private int getFirstWS(String s, int pos) {
+  private int getFirstWS(CharSequence s, int pos) {
     while (pos < s.length() && !StringUtil.isWhitespace(s.charAt(pos)))
       pos++;
     return pos;
   }
 
-  private int getFirstNonWS(String s, int pos) {
+  private int getFirstNonWS(CharSequence s, int pos) {
     while (pos < s.length() && StringUtil.isWhitespace(s.charAt(pos)))
       pos++;
     return pos;
   }
 
   /**
-   * Detect the position of the first words of sentences in a String.
+   * Detects the position of the first words of sentences in a {@link CharSequence}.
    *
-   * @param s  The string to be processed.
-   * @return   A integer array containing the positions of the end index of
-   *          every sentence
+   * @param s  The {@link CharSequence} to be processed.
+   * @return   An {@link Span span array} containing the positions of the end index of
+   *           every sentence.
    *
    */
-  public Span[] sentPosDetect(String s) {
+  @Override
+  public Span[] sentPosDetect(CharSequence s) {
     sentProbs.clear();
-    StringBuffer sb = new StringBuffer(s);
     List<Integer> enders = scanner.getPositions(s);
     List<Integer> positions = new ArrayList<>(enders.size());
 
@@ -187,7 +187,7 @@ public class SentenceDetectorME implements SentenceDetector {
       }
       if (positions.size() > 0 && cint < positions.get(positions.size() - 1)) continue;
 
-      double[] probs = model.eval(cgen.getContext(sb, cint));
+      double[] probs = model.eval(cgen.getContext(s, cint));
       String bestOutcome = model.getBestOutcome(probs);
 
       if (bestOutcome.equals(SPLIT) && isAcceptableBreak(s, index, cint)) {
@@ -278,10 +278,11 @@ public class SentenceDetectorME implements SentenceDetector {
 
   /**
    * Returns the probabilities associated with the most recent
-   * calls to sentDetect().
+   * calls to {@link SentenceDetectorME#sentDetect(CharSequence)}.
    *
-   * @return probability for each sentence returned for the most recent
-   *     call to sentDetect.  If not applicable an empty array is returned.
+   * @return The probability for each sentence returned for the most recent
+   *     call to {@link SentenceDetectorME#sentDetect(CharSequence)}.
+   *     If not applicable, an empty array is returned.
    */
   public double[] getSentenceProbabilities() {
     double[] sentProbArray = new double[sentProbs.size()];
@@ -296,15 +297,15 @@ public class SentenceDetectorME implements SentenceDetector {
    * trained) model from flagging obvious non-breaks as breaks based
    * on some boolean determination of a break's acceptability.
    *
-   * <p>The implementation here always returns true, which means
+   * <p>The implementation here always returns {@link true}, which means
    * that the MaxentModel's outcome is taken as is.</p>
    *
-   * @param s the string in which the break occurred.
-   * @param fromIndex the start of the segment currently being evaluated
-   * @param candidateIndex the index of the candidate sentence ending
-   * @return true if the break is acceptable
+   * @param s the {@link CharSequence} in which the break occurred.
+   * @param fromIndex the start of the segment currently being evaluated.
+   * @param candidateIndex the index of the candidate sentence ending.
+   * @return {@link true} if the break is acceptable.
    */
-  protected boolean isAcceptableBreak(String s, int fromIndex, int candidateIndex) {
+  protected boolean isAcceptableBreak(CharSequence s, int fromIndex, int candidateIndex) {
     return true;
   }
 
@@ -338,15 +339,4 @@ public class SentenceDetectorME implements SentenceDetector {
     return new SentenceModel(languageCode, sentModel, manifestInfoEntries, sdFactory);
   }
 
-  /**
-   * @deprecated Use
-   *             {@link #train(String, ObjectStream, SentenceDetectorFactory, TrainingParameters)}
-   *             and pass in af {@link SentenceDetectorFactory}.
-   */
-  @Deprecated
-  public static SentenceModel train(String languageCode, ObjectStream<SentenceSample> samples,
-      boolean useTokenEnd, Dictionary abbreviations) throws IOException {
-    return train(languageCode, samples, useTokenEnd, abbreviations,
-        ModelUtil.createDefaultTrainingParameters());
-  }
 }
