@@ -17,14 +17,13 @@
 
 package opennlp.tools.formats.masc;
 
-import java.io.File;
 import java.io.FileFilter;
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.List;
 
 import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.Test;
 
@@ -37,17 +36,21 @@ import opennlp.tools.util.ObjectStream;
 import opennlp.tools.util.Span;
 import opennlp.tools.util.TrainingParameters;
 
-public class MascSentenceSampleStreamTest {
+public class MascSentenceSampleStreamTest extends AbstractMascSampleStreamTest {
+  private MascSentenceSampleStream stream;
+
+  @BeforeEach
+  public void setup() throws IOException {
+    super.setup();
+    FileFilter fileFilter = pathname -> pathname.getName().contains("MASC");
+    stream = new MascSentenceSampleStream(
+             new MascDocumentStream(directory, true, fileFilter), 2);
+    Assertions.assertNotNull(stream);
+  }
 
   @Test
   void reset() {
-    FileFilter fileFilter = pathname -> pathname.getName().contains("MASC");
-    File directory = new File(this.getClass().getResource(
-        "/opennlp/tools/formats/masc/").getFile());
     try {
-      MascSentenceSampleStream stream = new MascSentenceSampleStream(
-          new MascDocumentStream(directory, true, fileFilter), 2);
-
       //exhaust the fake file
       SentenceSample testSample = stream.read();
 
@@ -65,7 +68,7 @@ public class MascSentenceSampleStreamTest {
       sentenceSpans.add(new Span(0, 24));
       sentenceSpans.add(new Span(25, 55));
       SentenceSample expectedSample = new SentenceSample(documentText,
-          sentenceSpans.toArray(new Span[sentenceSpans.size()]));
+          sentenceSpans.toArray(new Span[0]));
 
       Assertions.assertEquals(testSample.toString(), expectedSample.toString());
 
@@ -78,12 +81,6 @@ public class MascSentenceSampleStreamTest {
   void close() {
 
     try {
-      FileFilter fileFilter = pathname -> pathname.getName().contains("MASC");
-      File directory = new File(this.getClass().getResource(
-          "/opennlp/tools/formats/masc/").getFile());
-      MascSentenceSampleStream stream;
-      stream = new MascSentenceSampleStream(
-          new MascDocumentStream(directory, true, fileFilter), 2);
       stream.close();
       stream.read();
     } catch (IOException e) {
@@ -96,7 +93,6 @@ public class MascSentenceSampleStreamTest {
   @Test
   void read() {
     FileFilter fileFilter = pathname -> pathname.getName().contains("");
-    File directory = new File(this.getClass().getResource("/opennlp/tools/formats/masc").getFile());
     try {
       MascSentenceSampleStream stream = new MascSentenceSampleStream(
           new MascDocumentStream(directory, true, fileFilter), 2);
@@ -107,7 +103,7 @@ public class MascSentenceSampleStreamTest {
       sentenceSpans.add(new Span(25, 55));
 
       SentenceSample expectedSample = new SentenceSample(documentText,
-          sentenceSpans.toArray(new Span[sentenceSpans.size()]));
+          sentenceSpans.toArray(new Span[0]));
       SentenceSample testSample = stream.read();
       Assertions.assertEquals(testSample.toString(), expectedSample.toString());
 
@@ -116,25 +112,20 @@ public class MascSentenceSampleStreamTest {
       Assertions.assertNull(testSample);
 
     } catch (IOException e) {
-      System.out.println(e.getMessage());
-      System.out.println(Arrays.toString(e.getStackTrace()));
-      Assertions.fail("IO Exception");
+      Assertions.fail("IO Exception", e);
     }
 
   }
 
-  @Disabled //todo: We can't train on the FakeMasc data, it is too small.
   @Test
+  @Disabled //todo: We can't train on the FakeMasc data, it is too small.
   void train() {
     try {
-      File directory = new File(this.getClass().getResource(
-          "/opennlp/tools/formats/masc/").getFile());
       FileFilter fileFilter = pathname -> pathname.getName().contains("");
       ObjectStream<SentenceSample> trainSentences = new MascSentenceSampleStream(
           new MascDocumentStream(directory,
               true, fileFilter), 1);
 
-      System.out.println("Training");
       SentenceModel model = null;
       TrainingParameters trainingParameters = new TrainingParameters();
       trainingParameters.put(TrainingParameters.ITERATIONS_PARAM, 20);
@@ -147,12 +138,9 @@ public class MascSentenceSampleStreamTest {
       SentenceDetectorEvaluator evaluator = new SentenceDetectorEvaluator(
           new SentenceDetectorME(model));
       evaluator.evaluate(testPOS);
-      System.out.println(evaluator.getFMeasure());
 
     } catch (Exception e) {
-      System.err.println(e.getMessage());
-      System.err.println(Arrays.toString(e.getStackTrace()));
-      Assertions.fail("Exception raised");
+      Assertions.fail("Exception raised", e);
     }
 
 
