@@ -42,8 +42,7 @@ import opennlp.tools.util.TrainingParameters;
  */
 public class TokenizerFactoryTest {
 
-  private static ObjectStream<TokenSample> createSampleStream()
-      throws IOException {
+  private static ObjectStream<TokenSample> createSampleStream() throws IOException {
     InputStreamFactory in = new ResourceAsStreamFactory(
         TokenizerFactoryTest.class, "/opennlp/tools/tokenize/token.train");
 
@@ -66,18 +65,19 @@ public class TokenizerFactoryTest {
   void testDefault() throws IOException {
 
     Dictionary dic = loadAbbDictionary();
-    final String lang = "spa";
+    final String lang = "eng";
 
     TokenizerModel model = train(new TokenizerFactory(lang, dic, false, null));
 
     TokenizerFactory factory = model.getFactory();
-    Assertions.assertTrue(factory.getAbbreviationDictionary() != null);
+    Assertions.assertNotNull(factory.getAbbreviationDictionary());
     Assertions.assertTrue(factory.getContextGenerator() instanceof DefaultTokenContextGenerator);
 
-    Assertions.assertEquals(Factory.DEFAULT_ALPHANUMERIC, factory.getAlphaNumericPattern().pattern());
+    String defaultPattern = Factory.DEFAULT_ALPHANUMERIC.pattern();
+    Assertions.assertEquals(defaultPattern, factory.getAlphaNumericPattern().pattern());
     Assertions.assertEquals(lang, factory.getLanguageCode());
     Assertions.assertEquals(lang, model.getLanguage());
-    Assertions.assertFalse(factory.isUseAlphaNumericOptmization());
+    Assertions.assertFalse(factory.isUseAlphaNumericOptimization());
 
     ByteArrayOutputStream out = new ByteArrayOutputStream();
     model.serialize(out);
@@ -86,20 +86,20 @@ public class TokenizerFactoryTest {
     TokenizerModel fromSerialized = new TokenizerModel(in);
 
     factory = fromSerialized.getFactory();
-    Assertions.assertTrue(factory.getAbbreviationDictionary() != null);
+    Assertions.assertNotNull(factory.getAbbreviationDictionary());
     Assertions.assertTrue(factory.getContextGenerator() instanceof DefaultTokenContextGenerator);
 
-    Assertions.assertEquals(Factory.DEFAULT_ALPHANUMERIC, factory.getAlphaNumericPattern().pattern());
+    Assertions.assertEquals(defaultPattern, factory.getAlphaNumericPattern().pattern());
     Assertions.assertEquals(lang, factory.getLanguageCode());
     Assertions.assertEquals(lang, model.getLanguage());
-    Assertions.assertFalse(factory.isUseAlphaNumericOptmization());
+    Assertions.assertFalse(factory.isUseAlphaNumericOptimization());
   }
 
   @Test
   void testNullDict() throws IOException {
 
     Dictionary dic = null;
-    final String lang = "spa";
+    final String lang = "eng";
 
     TokenizerModel model = train(new TokenizerFactory(lang, dic, false, null));
 
@@ -107,10 +107,11 @@ public class TokenizerFactoryTest {
     Assertions.assertNull(factory.getAbbreviationDictionary());
     Assertions.assertTrue(factory.getContextGenerator() instanceof DefaultTokenContextGenerator);
 
-    Assertions.assertEquals(Factory.DEFAULT_ALPHANUMERIC, factory.getAlphaNumericPattern().pattern());
+    String defaultPattern = Factory.DEFAULT_ALPHANUMERIC.pattern();
+    Assertions.assertEquals(defaultPattern, factory.getAlphaNumericPattern().pattern());
     Assertions.assertEquals(lang, factory.getLanguageCode());
     Assertions.assertEquals(lang, model.getLanguage());
-    Assertions.assertFalse(factory.isUseAlphaNumericOptmization());
+    Assertions.assertFalse(factory.isUseAlphaNumericOptimization());
 
     ByteArrayOutputStream out = new ByteArrayOutputStream();
     model.serialize(out);
@@ -122,10 +123,10 @@ public class TokenizerFactoryTest {
     Assertions.assertNull(factory.getAbbreviationDictionary());
     Assertions.assertTrue(factory.getContextGenerator() instanceof DefaultTokenContextGenerator);
 
-    Assertions.assertEquals(Factory.DEFAULT_ALPHANUMERIC, factory.getAlphaNumericPattern().pattern());
+    Assertions.assertEquals(defaultPattern, factory.getAlphaNumericPattern().pattern());
     Assertions.assertEquals(lang, factory.getLanguageCode());
     Assertions.assertEquals(lang, model.getLanguage());
-    Assertions.assertFalse(factory.isUseAlphaNumericOptmization());
+    Assertions.assertFalse(factory.isUseAlphaNumericOptimization());
   }
 
   @Test
@@ -133,7 +134,7 @@ public class TokenizerFactoryTest {
 
     Dictionary dic = null;
     final String lang = "spa";
-    String pattern = "^[0-9A-Za-z]+$";
+    String pattern = "^[0-9a-záéíóúüýñA-ZÁÉÍÓÚÝÑ]+$";
 
     TokenizerModel model = train(new TokenizerFactory(lang, dic, true,
         Pattern.compile(pattern)));
@@ -145,7 +146,7 @@ public class TokenizerFactoryTest {
     Assertions.assertEquals(pattern, factory.getAlphaNumericPattern().pattern());
     Assertions.assertEquals(lang, factory.getLanguageCode());
     Assertions.assertEquals(lang, model.getLanguage());
-    Assertions.assertTrue(factory.isUseAlphaNumericOptmization());
+    Assertions.assertTrue(factory.isUseAlphaNumericOptimization());
 
     ByteArrayOutputStream out = new ByteArrayOutputStream();
     model.serialize(out);
@@ -159,14 +160,14 @@ public class TokenizerFactoryTest {
     Assertions.assertEquals(pattern, factory.getAlphaNumericPattern().pattern());
     Assertions.assertEquals(lang, factory.getLanguageCode());
     Assertions.assertEquals(lang, model.getLanguage());
-    Assertions.assertTrue(factory.isUseAlphaNumericOptmization());
+    Assertions.assertTrue(factory.isUseAlphaNumericOptimization());
   }
 
   @Test
   void testDummyFactory() throws IOException {
 
     Dictionary dic = loadAbbDictionary();
-    final String lang = "spa";
+    final String lang = "eng";
     String pattern = "^[0-9A-Za-z]+$";
 
     TokenizerModel model = train(new DummyTokenizerFactory(lang, dic, true,
@@ -178,7 +179,7 @@ public class TokenizerFactoryTest {
     Assertions.assertEquals(pattern, factory.getAlphaNumericPattern().pattern());
     Assertions.assertEquals(lang, factory.getLanguageCode());
     Assertions.assertEquals(lang, model.getLanguage());
-    Assertions.assertTrue(factory.isUseAlphaNumericOptmization());
+    Assertions.assertTrue(factory.isUseAlphaNumericOptimization());
 
     ByteArrayOutputStream out = new ByteArrayOutputStream();
     model.serialize(out);
@@ -192,13 +193,13 @@ public class TokenizerFactoryTest {
     Assertions.assertEquals(pattern, factory.getAlphaNumericPattern().pattern());
     Assertions.assertEquals(lang, factory.getLanguageCode());
     Assertions.assertEquals(lang, model.getLanguage());
-    Assertions.assertTrue(factory.isUseAlphaNumericOptmization());
+    Assertions.assertTrue(factory.isUseAlphaNumericOptimization());
   }
 
   @Test
   void testCreateDummyFactory() throws IOException {
     Dictionary dic = loadAbbDictionary();
-    final String lang = "spa";
+    final String lang = "eng";
     String pattern = "^[0-9A-Za-z]+$";
 
     TokenizerFactory factory = TokenizerFactory.create(
@@ -209,6 +210,6 @@ public class TokenizerFactoryTest {
     Assertions.assertTrue(factory.getContextGenerator() instanceof DummyContextGenerator);
     Assertions.assertEquals(pattern, factory.getAlphaNumericPattern().pattern());
     Assertions.assertEquals(lang, factory.getLanguageCode());
-    Assertions.assertTrue(factory.isUseAlphaNumericOptmization());
+    Assertions.assertTrue(factory.isUseAlphaNumericOptimization());
   }
 }
